/*******************************************************************************
 * Copyright (c) 2006, 2013 Oracle and/or its affiliates. All rights reserved.
 * This program and the accompanying materials are made available under the
 * terms of the Eclipse Public License v1.0 and Eclipse Distribution License v. 1.0
 * which accompanies this distribution.
 * The Eclipse Public License is available at http://www.eclipse.org/legal/epl-v10.html
 * and the Eclipse Distribution License is available at
 * http://www.eclipse.org/org/documents/edl-v10.php.
 *
 * Contributors:
 *     Oracle - initial API and implementation
 *
 ******************************************************************************/
package org.eclipse.persistence.tools.mapping.orm.dom;

import java.util.ArrayList;
import java.util.List;
import org.eclipse.persistence.tools.mapping.AbstractExternalForm;
import org.eclipse.persistence.tools.mapping.orm.ExternalTimeOfDay;
import org.eclipse.persistence.tools.utility.TextRange;

/**
 * The external form of a time of day, which is a child of an cache.
 *
 * @see Cache
 *
 * @version 2.6
 */
final class TimeOfDay extends AbstractExternalForm
                      implements ExternalTimeOfDay {

	/**
	 * Creates a new <code>TimeOfDay</code>.
	 *
	 * @param parent The parent of this external form
	 */
	TimeOfDay(Cache parent) {
		super(parent);
	}

	/**
	 * {@inheritDoc}
	 */
	@Override
	protected List<String> buildAttributeNamesOrder() {
		List<String> names = new ArrayList<String>();
		names.add(HOUR);
		names.add(MINUTE);
		names.add(SECOND);
		names.add(MILLISECOND);
		return names;
	}

	/**
	 * {@inheritDoc}
	 */
	@Override
	protected String getElementName() {
		return EXPIRY_TIME_OF_DAY;
	}

	/**
	 * {@inheritDoc}
	 */
	@Override
	public Integer getHour() {
		return getIntegerAttribute(HOUR);
	}

	/**
	 * {@inheritDoc}
	 */
	@Override
	public TextRange getHourTextRange() {
		return getAttributeTextRange(HOUR);
	}

	/**
	 * {@inheritDoc}
	 */
	@Override
	public Integer getMillisecond() {
		return getIntegerAttribute(MILLISECOND);
	}

	/**
	 * {@inheritDoc}
	 */
	@Override
	public TextRange getMillisecondTextRange() {
		return getAttributeTextRange(MILLISECOND);
	}

	/**
	 * {@inheritDoc}
	 */
	@Override
	public Integer getMinute() {
		return getIntegerAttribute(MINUTE);
	}

	/**
	 * {@inheritDoc}
	 */
	@Override
	public TextRange getMinuteTextRange() {
		return getAttributeTextRange(MINUTE);
	}

	/**
	 * {@inheritDoc}
	 */
	@Override
	public Integer getSecond() {
		return getIntegerAttribute(SECOND);
	}

	/**
	 * {@inheritDoc}
	 */
	@Override
	public TextRange getSecondTextRange() {
		return getAttributeTextRange(SECOND);
	}

	/**
	 * {@inheritDoc}
	 */
	@Override
	public void setHour(Integer hour) {
		setAttribute(HOUR, hour);
	}

	/**
	 * {@inheritDoc}
	 */
	@Override
	public void setMillisecond(Integer millisecond) {
		setAttribute(MILLISECOND, millisecond);
	}

	/**
	 * {@inheritDoc}
	 */
	@Override
	public void setMinute(Integer minute) {
		setAttribute(MINUTE, minute);
	}

	/**
	 * {@inheritDoc}
	 */
	@Override
	public void setSecond(Integer second) {
		setAttribute(SECOND, second);
	}
}